==> gazie7.30.zip: gazie/modules/acquis/menu.spanish.php <==
<?php

/*
  --------------------------------------------------------------------------
  GAzie - Gestione Azienda
  Copyright (C) 2004-2020 - Antonio De Vincentiis Montesilvano (PE)
  (http://www.devincentiis.it)
  <http://gazie.sourceforge.net>
  --------------------------------------------------------------------------
  Questo programma e` free software;   e` lecito redistribuirlo  e/o
  modificarlo secondo i  termini della Licenza Pubblica Generica GNU
  come e` pubblicata dalla Free Software Foundation; o la versione 2
  della licenza o (a propria scelta) una versione successiva.

  Questo programma  e` distribuito nella speranza  che sia utile, ma
  SENZA   ALCUNA GARANZIA; senza  neppure  la  garanzia implicita di
  NEGOZIABILITA` o di  APPLICABILITA` PER UN  PARTICOLARE SCOPO.  Si
  veda la Licenza Pubblica Generica GNU per avere maggiori dettagli.

  Ognuno dovrebbe avere   ricevuto una copia  della Licenza Pubblica
  Generica GNU insieme a   questo programma; in caso  contrario,  si
  scriva   alla   Free  Software Foundation, 51 Franklin Street,
  Fifth Floor Boston, MA 02110-1335 USA Stati Uniti.
  --------------------------------------------------------------------------
 */

/*
  -- TRANSLATED BY : Dante Becerra Lagos (softenglish@gmail.com)
 */

$transl['acquis'] = array('name' => "Compras",
    'title' => "Administracion de Compras",
    'm2' => array(1 => array("Administracion de pedidos y de las estimaciones de los proveedores", "Estimacion y Pedido"),
        2 => array("Administracion de notas de entrega de los proveedores", "Notas de entrega"),
        3 => array("Administracion de Factura de Compras", "Factura de Compras"),
        4 => array("Reporte de cuentas pagables", "Cuentas pagables"),
        5 => array("Administracion de proveedores", "Proveedores"),
        6 => array("Ver e imprimir reporte de debito", "Reporte de debito"),
        7 => array("Imprimir nota de combustible", "Nota de combustible"),
        8 => array("Scadenzario a partite aperte", "Scadenzario"),
        9 => array("Agenti di Fornitori", "Agenti")
    ),
    'm3' => array(1 => array("Solicitar una cotizacion al proveedor", "Solicitar cotizacion"),
        2 => array("Pedido a proveedor", "Pedido a proveedor"),
        3 => array("Emitir Notas de Entrega para devorlver al proveedor", "Notas de Entrega al proveedor"),
        4 => array("Emisi&oacute;n de Notas de entrega para procesamiento", "Notas de entrega para procesamiento"),
        5 => array("Registro de Factura de Compra", "Ingresar Factura"),
        6 => array("Registro de nota de credito de compra", " Ingresar nota de credito"),
        7 => array("Contabilidad de facturas de compra", "Contabilidad de facturas"),
        8 => array("Inserte nuevo proveedor", "Nuevo proveedor"),
        9 => array("Reporte de Notas de Entrega de Compra", "Reporte de Notas de Entrega"),
        10 => array("Notas de Entrega recibidas del proveedor", "Nuevas Notas de Entrega"),
        11 => array("Pagamento di un debito vantato da un fornitore", "Pagamento debito verso fornitore"),
        12 => array("Report partite aperte", "Report partite aperte"),
        13 => array("Selezione e stampa stato clienti", "Stato delle scadenze"),
        14 => array("Inserimento nuovo agente di fornitori", "Nuovo agente"),
        15 => array("Stampa lista clienti", "Lista clienti"),
        16 => array("Purchase depreciable asset", "Purchase depreciable asset"),
        17 => array("Pagamento RiBa fornitori", "Paga RiBa a fornitori"),
		18 => array("Orden automática del vendedor", "Orden automática del vendedor"),
		19 => array("Acquisisci fattura elettronica", "Acquisisci fattura elettronica"),
        20 => array("Ricevuto DdT ritorno da lavorazione", "Ricevuto DdT ritorno da lavorazione")
    )
);
?>

==> gazie8.00.zip: gazie/modules/acquis/menu.spanish.php <==
<?php

/*
  --------------------------------------------------------------------------
  GAzie - Gestione Azienda
  Copyright (C) 2004-2021 - Antonio De Vincentiis Montesilvano (PE)
  (http://www.devincentiis.it)
  <http://gazie.sourceforge.net>
  --------------------------------------------------------------------------
  Questo programma e` free software;   e` lecito redistribuirlo  e/o
  modificarlo secondo i  termini della Licenza Pubblica Generica GNU
  come e` pubblicata dalla Free Software Foundation; o la versione 2
  della licenza o (a propria scelta) una versione successiva.

  Questo programma  e` distribuito nella speranza  che sia utile, ma
  SENZA   ALCUNA GARANZIA; senza  neppure  la  garanzia implicita di
  NEGOZIABILITA` o di  APPLICABILITA` PER UN  PARTICOLARE SCOPO.  Si
  veda la Licenza Pubblica Generica GNU per avere maggiori dettagli.

  Ognuno dovrebbe avere   ricevuto una copia  della Licenza Pubblica
  Generica GNU insieme a   questo programma; in caso  contrario,  si
  scriva   alla   Free  Software Foundation, 51 Franklin Street,
  Fifth Floor Boston, MA 02110-1335 USA Stati Uniti.
  --------------------------------------------------------------------------
 */

/*
  -- TRANSLATED BY : Dante Becerra Lagos (softenglish@gmail.com)
 */

$transl['acquis'] = array('name' => "Compras",
    'title' => "Administracion de Compras",
    'm2' => array(1 => array("Administracion de pedidos y de las estimaciones de los proveedores", "Estimacion y Pedido"),
        2 => array("Administracion de notas de entrega de los proveedores", "Notas de entrega"),
        3 => array("Administracion de Factura de Compras", "Factura de Compras"),
        4 => array("Reporte de cuentas pagables", "Cuentas pagables"),
        5 => array("Administracion de proveedores", "Proveedores"),
        6 => array("Ver e imprimir reporte de debito", "Reporte de debito"),
        7 => array("Imprimir nota de combustible", "Nota de combustible"),
        8 => array("Scadenzario a partite aperte", "Scadenzario"),
        9 => array("Agenti di Fornitori", "Agenti"),
        10 => array("Gestione Ordini a Fornitori", "Ordini")
    ),
    'm3' => array(1 => array("Solicitar una cotizacion al proveedor", "Solicitar cotizacion"),
        2 => array("Pedido a proveedor", "Pedido a proveedor"),
        3 => array("Emitir Notas de Entrega para devorlver al proveedor", "Notas de Entrega al proveedor"),
        4 => array("Emisi&oacute;n de Notas de entrega para procesamiento", "Notas de entrega para procesamiento"),
        5 => array("Registro de Factura de Compra", "Ingresar Factura"),
        6 => array("Registro de nota de credito de compra", " Ingresar nota de credito"),
        7 => array("Contabilidad de facturas de compra", "Contabilidad de facturas"),
        8 => array("Inserte nuevo proveedor", "Nuevo proveedor"),
        9 => array("Reporte de Notas de Entrega de Compra", "Reporte de Notas de Entrega"),
        10 => array("Notas de Entrega recibidas del proveedor", "Nuevas Notas de Entrega"),
        11 => array("Pagamento di un debito vantato da un fornitore", "Pagamento debito verso fornitore"),
        12 => array("Report partite aperte", "Report partite aperte"),
        13 => array("Selezione e stampa stato clienti", "Stato delle scadenze"),
        14 => array("Inserimento nuovo agente di fornitori", "Nuovo agente"),
        15 => array("Stampa lista clienti", "Lista clienti"),
        16 => array("Purchase depreciable asset", "Purchase depreciable asset"),
        17 => array("Pagamento RiBa fornitori", "Paga RiBa a fornitori"),
		18 => array("Orden automática del vendedor", "Orden automática del vendedor"),
		19 => array("Acquisisci fattura elettronica", "Acquisisci fattura elettronica"),
        20 => array("Ricevuto DdT ritorno da lavorazione", "Ricevuto DdT ritorno da lavorazione"),
        21 => array("Genera XML-CBI bonifico", "Genera XML-CBI bonifico")
    )
);
?>
